@@ -10,11 +10,39 @@ Usage::
     client: CodeBuildClient = boto3.client("codebuild")
     ```
 """
-import sys
 from typing import Any, Dict, List, Type, overload
 
 from botocore.client import ClientMeta
 
+from mypy_boto3_codebuild.literals import (
+    AuthType,
+    ComputeType,
+    DescribeCodeCoveragesPaginatorName,
+    DescribeTestCasesPaginatorName,
+    EnvironmentType,
+    ImagePullCredentialsType,
+    ListBuildBatchesForProjectPaginatorName,
+    ListBuildBatchesPaginatorName,
+    ListBuildsForProjectPaginatorName,
+    ListBuildsPaginatorName,
+    ListProjectsPaginatorName,
+    ListReportGroupsPaginatorName,
+    ListReportsForReportGroupPaginatorName,
+    ListReportsPaginatorName,
+    ListSharedProjectsPaginatorName,
+    ListSharedReportGroupsPaginatorName,
+    ProjectSortByType,
+    ReportCodeCoverageSortByType,
+    ReportGroupSortByType,
+    ReportGroupTrendFieldType,
+    ReportType,
+    RetryBuildBatchType,
+    ServerType,
+    SharedResourceSortByType,
+    SortOrderType,
+    SourceType,
+    WebhookBuildType,
+)
 from mypy_boto3_codebuild.paginator import (
     DescribeCodeCoveragesPaginator,
     DescribeTestCasesPaginator,
@@ -90,12 +118,6 @@ from mypy_boto3_codebuild.type_defs import (
     WebhookFilterTypeDef,
 )
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
-
 __all__ = ("CodeBuildClient",)
 
 
@@ -118,7 +140,7 @@ class Exceptions:
 
 class CodeBuildClient:
     """
-    [CodeBuild.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Client)
+    [CodeBuild.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Client)
     """
 
     meta: ClientMeta
@@ -126,39 +148,39 @@ class CodeBuildClient:
 
     def batch_delete_builds(self, ids: List[str]) -> BatchDeleteBuildsOutputTypeDef:
         """
-        [Client.batch_delete_builds documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Client.batch_delete_builds)
+        [Client.batch_delete_builds documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Client.batch_delete_builds)
         """
 
     def batch_get_build_batches(self, ids: List[str]) -> BatchGetBuildBatchesOutputTypeDef:
         """
-        [Client.batch_get_build_batches documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Client.batch_get_build_batches)
+        [Client.batch_get_build_batches documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Client.batch_get_build_batches)
         """
 
     def batch_get_builds(self, ids: List[str]) -> BatchGetBuildsOutputTypeDef:
         """
-        [Client.batch_get_builds documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Client.batch_get_builds)
+        [Client.batch_get_builds documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Client.batch_get_builds)
         """
 
     def batch_get_projects(self, names: List[str]) -> BatchGetProjectsOutputTypeDef:
         """
-        [Client.batch_get_projects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Client.batch_get_projects)
+        [Client.batch_get_projects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Client.batch_get_projects)
         """
 
     def batch_get_report_groups(
         self, reportGroupArns: List[str]
     ) -> BatchGetReportGroupsOutputTypeDef:
         """
-        [Client.batch_get_report_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Client.batch_get_report_groups)
+        [Client.batch_get_report_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Client.batch_get_report_groups)
         """
 
     def batch_get_reports(self, reportArns: List[str]) -> BatchGetReportsOutputTypeDef:
         """
-        [Client.batch_get_reports documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Client.batch_get_reports)
+        [Client.batch_get_reports documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Client.batch_get_reports)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Client.can_paginate)
         """
 
     def create_project(
@@ -186,18 +208,18 @@ class CodeBuildClient:
         concurrentBuildLimit: int = None,
     ) -> CreateProjectOutputTypeDef:
         """
-        [Client.create_project documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Client.create_project)
+        [Client.create_project documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Client.create_project)
         """
 
     def create_report_group(
         self,
         name: str,
-        type: Literal["TEST", "CODE_COVERAGE"],
+        type: ReportType,
         exportConfig: "ReportExportConfigTypeDef",
         tags: List["TagTypeDef"] = None,
     ) -> CreateReportGroupOutputTypeDef:
         """
-        [Client.create_report_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Client.create_report_group)
+        [Client.create_report_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Client.create_report_group)
         """
 
     def create_webhook(
@@ -205,45 +227,45 @@ class CodeBuildClient:
         projectName: str,
         branchFilter: str = None,
         filterGroups: List[List["WebhookFilterTypeDef"]] = None,
-        buildType: Literal["BUILD", "BUILD_BATCH"] = None,
+        buildType: WebhookBuildType = None,
     ) -> CreateWebhookOutputTypeDef:
         """
-        [Client.create_webhook documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Client.create_webhook)
+        [Client.create_webhook documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Client.create_webhook)
         """
 
     def delete_build_batch(self, id: str) -> DeleteBuildBatchOutputTypeDef:
         """
-        [Client.delete_build_batch documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Client.delete_build_batch)
+        [Client.delete_build_batch documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Client.delete_build_batch)
         """
 
     def delete_project(self, name: str) -> Dict[str, Any]:
         """
-        [Client.delete_project documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Client.delete_project)
+        [Client.delete_project documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Client.delete_project)
         """
 
     def delete_report(self, arn: str) -> Dict[str, Any]:
         """
-        [Client.delete_report documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Client.delete_report)
+        [Client.delete_report documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Client.delete_report)
         """
 
     def delete_report_group(self, arn: str, deleteReports: bool = None) -> Dict[str, Any]:
         """
-        [Client.delete_report_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Client.delete_report_group)
+        [Client.delete_report_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Client.delete_report_group)
         """
 
     def delete_resource_policy(self, resourceArn: str) -> Dict[str, Any]:
         """
-        [Client.delete_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Client.delete_resource_policy)
+        [Client.delete_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Client.delete_resource_policy)
         """
 
     def delete_source_credentials(self, arn: str) -> DeleteSourceCredentialsOutputTypeDef:
         """
-        [Client.delete_source_credentials documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Client.delete_source_credentials)
+        [Client.delete_source_credentials documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Client.delete_source_credentials)
         """
 
     def delete_webhook(self, projectName: str) -> Dict[str, Any]:
         """
-        [Client.delete_webhook documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Client.delete_webhook)
+        [Client.delete_webhook documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Client.delete_webhook)
         """
 
     def describe_code_coverages(
@@ -251,13 +273,13 @@ class CodeBuildClient:
         reportArn: str,
         nextToken: str = None,
         maxResults: int = None,
-        sortOrder: Literal["ASCENDING", "DESCENDING"] = None,
-        sortBy: Literal["LINE_COVERAGE_PERCENTAGE", "FILE_PATH"] = None,
+        sortOrder: SortOrderType = None,
+        sortBy: ReportCodeCoverageSortByType = None,
         minLineCoveragePercentage: float = None,
         maxLineCoveragePercentage: float = None,
     ) -> DescribeCodeCoveragesOutputTypeDef:
         """
-        [Client.describe_code_coverages documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Client.describe_code_coverages)
+        [Client.describe_code_coverages documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Client.describe_code_coverages)
         """
 
     def describe_test_cases(
@@ -268,7 +290,7 @@ class CodeBuildClient:
         filter: TestCaseFilterTypeDef = None,
     ) -> DescribeTestCasesOutputTypeDef:
         """
-        [Client.describe_test_cases documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Client.describe_test_cases)
+        [Client.describe_test_cases documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Client.describe_test_cases)
         """
 
     def generate_presigned_url(
@@ -279,60 +301,47 @@ class CodeBuildClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Client.generate_presigned_url)
         """
 
     def get_report_group_trend(
-        self,
-        reportGroupArn: str,
-        trendField: Literal[
-            "PASS_RATE",
-            "DURATION",
-            "TOTAL",
-            "LINE_COVERAGE",
-            "LINES_COVERED",
-            "LINES_MISSED",
-            "BRANCH_COVERAGE",
-            "BRANCHES_COVERED",
-            "BRANCHES_MISSED",
-        ],
-        numOfReports: int = None,
+        self, reportGroupArn: str, trendField: ReportGroupTrendFieldType, numOfReports: int = None
     ) -> GetReportGroupTrendOutputTypeDef:
         """
-        [Client.get_report_group_trend documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Client.get_report_group_trend)
+        [Client.get_report_group_trend documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Client.get_report_group_trend)
         """
 
     def get_resource_policy(self, resourceArn: str) -> GetResourcePolicyOutputTypeDef:
         """
-        [Client.get_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Client.get_resource_policy)
+        [Client.get_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Client.get_resource_policy)
         """
 
     def import_source_credentials(
         self,
         token: str,
-        serverType: Literal["GITHUB", "BITBUCKET", "GITHUB_ENTERPRISE"],
-        authType: Literal["OAUTH", "BASIC_AUTH", "PERSONAL_ACCESS_TOKEN"],
+        serverType: ServerType,
+        authType: AuthType,
         username: str = None,
         shouldOverwrite: bool = None,
     ) -> ImportSourceCredentialsOutputTypeDef:
         """
-        [Client.import_source_credentials documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Client.import_source_credentials)
+        [Client.import_source_credentials documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Client.import_source_credentials)
         """
 
     def invalidate_project_cache(self, projectName: str) -> Dict[str, Any]:
         """
-        [Client.invalidate_project_cache documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Client.invalidate_project_cache)
+        [Client.invalidate_project_cache documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Client.invalidate_project_cache)
         """
 
     def list_build_batches(
         self,
         filter: BuildBatchFilterTypeDef = None,
         maxResults: int = None,
-        sortOrder: Literal["ASCENDING", "DESCENDING"] = None,
+        sortOrder: SortOrderType = None,
         nextToken: str = None,
     ) -> ListBuildBatchesOutputTypeDef:
         """
-        [Client.list_build_batches documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Client.list_build_batches)
+        [Client.list_build_batches documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Client.list_build_batches)
         """
 
     def list_build_batches_for_project(
@@ -340,124 +349,118 @@ class CodeBuildClient:
         projectName: str = None,
         filter: BuildBatchFilterTypeDef = None,
         maxResults: int = None,
-        sortOrder: Literal["ASCENDING", "DESCENDING"] = None,
+        sortOrder: SortOrderType = None,
         nextToken: str = None,
     ) -> ListBuildBatchesForProjectOutputTypeDef:
         """
-        [Client.list_build_batches_for_project documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Client.list_build_batches_for_project)
+        [Client.list_build_batches_for_project documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Client.list_build_batches_for_project)
         """
 
     def list_builds(
-        self, sortOrder: Literal["ASCENDING", "DESCENDING"] = None, nextToken: str = None
+        self, sortOrder: SortOrderType = None, nextToken: str = None
     ) -> ListBuildsOutputTypeDef:
         """
-        [Client.list_builds documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Client.list_builds)
+        [Client.list_builds documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Client.list_builds)
         """
 
     def list_builds_for_project(
-        self,
-        projectName: str,
-        sortOrder: Literal["ASCENDING", "DESCENDING"] = None,
-        nextToken: str = None,
+        self, projectName: str, sortOrder: SortOrderType = None, nextToken: str = None
     ) -> ListBuildsForProjectOutputTypeDef:
         """
-        [Client.list_builds_for_project documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Client.list_builds_for_project)
+        [Client.list_builds_for_project documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Client.list_builds_for_project)
         """
 
     def list_curated_environment_images(self) -> ListCuratedEnvironmentImagesOutputTypeDef:
         """
-        [Client.list_curated_environment_images documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Client.list_curated_environment_images)
+        [Client.list_curated_environment_images documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Client.list_curated_environment_images)
         """
 
     def list_projects(
         self,
-        sortBy: Literal["NAME", "CREATED_TIME", "LAST_MODIFIED_TIME"] = None,
-        sortOrder: Literal["ASCENDING", "DESCENDING"] = None,
+        sortBy: ProjectSortByType = None,
+        sortOrder: SortOrderType = None,
         nextToken: str = None,
     ) -> ListProjectsOutputTypeDef:
         """
-        [Client.list_projects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Client.list_projects)
+        [Client.list_projects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Client.list_projects)
         """
 
     def list_report_groups(
         self,
-        sortOrder: Literal["ASCENDING", "DESCENDING"] = None,
-        sortBy: Literal["NAME", "CREATED_TIME", "LAST_MODIFIED_TIME"] = None,
+        sortOrder: SortOrderType = None,
+        sortBy: ReportGroupSortByType = None,
         nextToken: str = None,
         maxResults: int = None,
     ) -> ListReportGroupsOutputTypeDef:
         """
-        [Client.list_report_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Client.list_report_groups)
+        [Client.list_report_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Client.list_report_groups)
         """
 
     def list_reports(
         self,
-        sortOrder: Literal["ASCENDING", "DESCENDING"] = None,
+        sortOrder: SortOrderType = None,
         nextToken: str = None,
         maxResults: int = None,
         filter: ReportFilterTypeDef = None,
     ) -> ListReportsOutputTypeDef:
         """
-        [Client.list_reports documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Client.list_reports)
+        [Client.list_reports documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Client.list_reports)
         """
 
     def list_reports_for_report_group(
         self,
         reportGroupArn: str,
         nextToken: str = None,
-        sortOrder: Literal["ASCENDING", "DESCENDING"] = None,
+        sortOrder: SortOrderType = None,
         maxResults: int = None,
         filter: ReportFilterTypeDef = None,
     ) -> ListReportsForReportGroupOutputTypeDef:
         """
-        [Client.list_reports_for_report_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Client.list_reports_for_report_group)
+        [Client.list_reports_for_report_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Client.list_reports_for_report_group)
         """
 
     def list_shared_projects(
         self,
-        sortBy: Literal["ARN", "MODIFIED_TIME"] = None,
-        sortOrder: Literal["ASCENDING", "DESCENDING"] = None,
+        sortBy: SharedResourceSortByType = None,
+        sortOrder: SortOrderType = None,
         maxResults: int = None,
         nextToken: str = None,
     ) -> ListSharedProjectsOutputTypeDef:
         """
-        [Client.list_shared_projects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Client.list_shared_projects)
+        [Client.list_shared_projects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Client.list_shared_projects)
         """
 
     def list_shared_report_groups(
         self,
-        sortOrder: Literal["ASCENDING", "DESCENDING"] = None,
-        sortBy: Literal["ARN", "MODIFIED_TIME"] = None,
+        sortOrder: SortOrderType = None,
+        sortBy: SharedResourceSortByType = None,
         nextToken: str = None,
         maxResults: int = None,
     ) -> ListSharedReportGroupsOutputTypeDef:
         """
-        [Client.list_shared_report_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Client.list_shared_report_groups)
+        [Client.list_shared_report_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Client.list_shared_report_groups)
         """
 
     def list_source_credentials(self) -> ListSourceCredentialsOutputTypeDef:
         """
-        [Client.list_source_credentials documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Client.list_source_credentials)
+        [Client.list_source_credentials documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Client.list_source_credentials)
         """
 
     def put_resource_policy(self, policy: str, resourceArn: str) -> PutResourcePolicyOutputTypeDef:
         """
-        [Client.put_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Client.put_resource_policy)
+        [Client.put_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Client.put_resource_policy)
         """
 
     def retry_build(self, id: str = None, idempotencyToken: str = None) -> RetryBuildOutputTypeDef:
         """
-        [Client.retry_build documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Client.retry_build)
+        [Client.retry_build documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Client.retry_build)
         """
 
     def retry_build_batch(
-        self,
-        id: str = None,
-        idempotencyToken: str = None,
-        retryType: Literal["RETRY_ALL_BUILDS", "RETRY_FAILED_BUILDS"] = None,
+        self, id: str = None, idempotencyToken: str = None, retryType: RetryBuildBatchType = None
     ) -> RetryBuildBatchOutputTypeDef:
         """
-        [Client.retry_build_batch documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Client.retry_build_batch)
+        [Client.retry_build_batch documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Client.retry_build_batch)
         """
 
     def start_build(
@@ -469,15 +472,7 @@ class CodeBuildClient:
         artifactsOverride: "ProjectArtifactsTypeDef" = None,
         secondaryArtifactsOverride: List["ProjectArtifactsTypeDef"] = None,
         environmentVariablesOverride: List["EnvironmentVariableTypeDef"] = None,
-        sourceTypeOverride: Literal[
-            "CODECOMMIT",
-            "CODEPIPELINE",
-            "GITHUB",
-            "S3",
-            "BITBUCKET",
-            "GITHUB_ENTERPRISE",
-            "NO_SOURCE",
-        ] = None,
+        sourceTypeOverride: SourceType = None,
         sourceLocationOverride: str = None,
         sourceAuthOverride: "SourceAuthTypeDef" = None,
         gitCloneDepthOverride: int = None,
@@ -486,20 +481,9 @@ class CodeBuildClient:
         insecureSslOverride: bool = None,
         reportBuildStatusOverride: bool = None,
         buildStatusConfigOverride: "BuildStatusConfigTypeDef" = None,
-        environmentTypeOverride: Literal[
-            "WINDOWS_CONTAINER",
-            "LINUX_CONTAINER",
-            "LINUX_GPU_CONTAINER",
-            "ARM_CONTAINER",
-            "WINDOWS_SERVER_2019_CONTAINER",
-        ] = None,
+        environmentTypeOverride: EnvironmentType = None,
         imageOverride: str = None,
-        computeTypeOverride: Literal[
-            "BUILD_GENERAL1_SMALL",
-            "BUILD_GENERAL1_MEDIUM",
-            "BUILD_GENERAL1_LARGE",
-            "BUILD_GENERAL1_2XLARGE",
-        ] = None,
+        computeTypeOverride: ComputeType = None,
         certificateOverride: str = None,
         cacheOverride: "ProjectCacheTypeDef" = None,
         serviceRoleOverride: str = None,
@@ -510,11 +494,11 @@ class CodeBuildClient:
         idempotencyToken: str = None,
         logsConfigOverride: "LogsConfigTypeDef" = None,
         registryCredentialOverride: "RegistryCredentialTypeDef" = None,
-        imagePullCredentialsTypeOverride: Literal["CODEBUILD", "SERVICE_ROLE"] = None,
+        imagePullCredentialsTypeOverride: ImagePullCredentialsType = None,
         debugSessionEnabled: bool = None,
     ) -> StartBuildOutputTypeDef:
         """
-        [Client.start_build documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Client.start_build)
+        [Client.start_build documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Client.start_build)
         """
 
     def start_build_batch(
@@ -526,15 +510,7 @@ class CodeBuildClient:
         artifactsOverride: "ProjectArtifactsTypeDef" = None,
         secondaryArtifactsOverride: List["ProjectArtifactsTypeDef"] = None,
         environmentVariablesOverride: List["EnvironmentVariableTypeDef"] = None,
-        sourceTypeOverride: Literal[
-            "CODECOMMIT",
-            "CODEPIPELINE",
-            "GITHUB",
-            "S3",
-            "BITBUCKET",
-            "GITHUB_ENTERPRISE",
-            "NO_SOURCE",
-        ] = None,
+        sourceTypeOverride: SourceType = None,
         sourceLocationOverride: str = None,
         sourceAuthOverride: "SourceAuthTypeDef" = None,
         gitCloneDepthOverride: int = None,
@@ -542,20 +518,9 @@ class CodeBuildClient:
         buildspecOverride: str = None,
         insecureSslOverride: bool = None,
         reportBuildBatchStatusOverride: bool = None,
-        environmentTypeOverride: Literal[
-            "WINDOWS_CONTAINER",
-            "LINUX_CONTAINER",
-            "LINUX_GPU_CONTAINER",
-            "ARM_CONTAINER",
-            "WINDOWS_SERVER_2019_CONTAINER",
-        ] = None,
+        environmentTypeOverride: EnvironmentType = None,
         imageOverride: str = None,
-        computeTypeOverride: Literal[
-            "BUILD_GENERAL1_SMALL",
-            "BUILD_GENERAL1_MEDIUM",
-            "BUILD_GENERAL1_LARGE",
-            "BUILD_GENERAL1_2XLARGE",
-        ] = None,
+        computeTypeOverride: ComputeType = None,
         certificateOverride: str = None,
         cacheOverride: "ProjectCacheTypeDef" = None,
         serviceRoleOverride: str = None,
@@ -566,22 +531,22 @@ class CodeBuildClient:
         idempotencyToken: str = None,
         logsConfigOverride: "LogsConfigTypeDef" = None,
         registryCredentialOverride: "RegistryCredentialTypeDef" = None,
-        imagePullCredentialsTypeOverride: Literal["CODEBUILD", "SERVICE_ROLE"] = None,
+        imagePullCredentialsTypeOverride: ImagePullCredentialsType = None,
         buildBatchConfigOverride: "ProjectBuildBatchConfigTypeDef" = None,
         debugSessionEnabled: bool = None,
     ) -> StartBuildBatchOutputTypeDef:
         """
-        [Client.start_build_batch documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Client.start_build_batch)
+        [Client.start_build_batch documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Client.start_build_batch)
         """
 
     def stop_build(self, id: str) -> StopBuildOutputTypeDef:
         """
-        [Client.stop_build documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Client.stop_build)
+        [Client.stop_build documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Client.stop_build)
         """
 
     def stop_build_batch(self, id: str) -> StopBuildBatchOutputTypeDef:
         """
-        [Client.stop_build_batch documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Client.stop_build_batch)
+        [Client.stop_build_batch documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Client.stop_build_batch)
         """
 
     def update_project(
@@ -609,7 +574,7 @@ class CodeBuildClient:
         concurrentBuildLimit: int = None,
     ) -> UpdateProjectOutputTypeDef:
         """
-        [Client.update_project documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Client.update_project)
+        [Client.update_project documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Client.update_project)
         """
 
     def update_report_group(
@@ -619,7 +584,7 @@ class CodeBuildClient:
         tags: List["TagTypeDef"] = None,
     ) -> UpdateReportGroupOutputTypeDef:
         """
-        [Client.update_report_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Client.update_report_group)
+        [Client.update_report_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Client.update_report_group)
         """
 
     def update_webhook(
@@ -628,98 +593,98 @@ class CodeBuildClient:
         branchFilter: str = None,
         rotateSecret: bool = None,
         filterGroups: List[List["WebhookFilterTypeDef"]] = None,
-        buildType: Literal["BUILD", "BUILD_BATCH"] = None,
+        buildType: WebhookBuildType = None,
     ) -> UpdateWebhookOutputTypeDef:
         """
-        [Client.update_webhook documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Client.update_webhook)
+        [Client.update_webhook documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Client.update_webhook)
         """
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["describe_code_coverages"]
+        self, operation_name: DescribeCodeCoveragesPaginatorName
     ) -> DescribeCodeCoveragesPaginator:
         """
-        [Paginator.DescribeCodeCoverages documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Paginator.DescribeCodeCoverages)
+        [Paginator.DescribeCodeCoverages documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Paginator.DescribeCodeCoverages)
         """
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["describe_test_cases"]
+        self, operation_name: DescribeTestCasesPaginatorName
     ) -> DescribeTestCasesPaginator:
         """
-        [Paginator.DescribeTestCases documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Paginator.DescribeTestCases)
+        [Paginator.DescribeTestCases documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Paginator.DescribeTestCases)
         """
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["list_build_batches"]
+        self, operation_name: ListBuildBatchesPaginatorName
     ) -> ListBuildBatchesPaginator:
         """
-        [Paginator.ListBuildBatches documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildBatches)
+        [Paginator.ListBuildBatches documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildBatches)
         """
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["list_build_batches_for_project"]
+        self, operation_name: ListBuildBatchesForProjectPaginatorName
     ) -> ListBuildBatchesForProjectPaginator:
         """
-        [Paginator.ListBuildBatchesForProject documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildBatchesForProject)
+        [Paginator.ListBuildBatchesForProject documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildBatchesForProject)
         """
 
     @overload
-    def get_paginator(self, operation_name: Literal["list_builds"]) -> ListBuildsPaginator:
+    def get_paginator(self, operation_name: ListBuildsPaginatorName) -> ListBuildsPaginator:
         """
-        [Paginator.ListBuilds documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Paginator.ListBuilds)
+        [Paginator.ListBuilds documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Paginator.ListBuilds)
         """
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["list_builds_for_project"]
+        self, operation_name: ListBuildsForProjectPaginatorName
     ) -> ListBuildsForProjectPaginator:
         """
-        [Paginator.ListBuildsForProject documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildsForProject)
+        [Paginator.ListBuildsForProject documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildsForProject)
         """
 
     @overload
-    def get_paginator(self, operation_name: Literal["list_projects"]) -> ListProjectsPaginator:
+    def get_paginator(self, operation_name: ListProjectsPaginatorName) -> ListProjectsPaginator:
         """
-        [Paginator.ListProjects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Paginator.ListProjects)
+        [Paginator.ListProjects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Paginator.ListProjects)
         """
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["list_report_groups"]
+        self, operation_name: ListReportGroupsPaginatorName
     ) -> ListReportGroupsPaginator:
         """
-        [Paginator.ListReportGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Paginator.ListReportGroups)
+        [Paginator.ListReportGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Paginator.ListReportGroups)
         """
 
     @overload
-    def get_paginator(self, operation_name: Literal["list_reports"]) -> ListReportsPaginator:
+    def get_paginator(self, operation_name: ListReportsPaginatorName) -> ListReportsPaginator:
         """
-        [Paginator.ListReports documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Paginator.ListReports)
+        [Paginator.ListReports documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Paginator.ListReports)
         """
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["list_reports_for_report_group"]
+        self, operation_name: ListReportsForReportGroupPaginatorName
     ) -> ListReportsForReportGroupPaginator:
         """
-        [Paginator.ListReportsForReportGroup documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Paginator.ListReportsForReportGroup)
+        [Paginator.ListReportsForReportGroup documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Paginator.ListReportsForReportGroup)
         """
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["list_shared_projects"]
+        self, operation_name: ListSharedProjectsPaginatorName
     ) -> ListSharedProjectsPaginator:
         """
-        [Paginator.ListSharedProjects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedProjects)
+        [Paginator.ListSharedProjects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedProjects)
         """
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["list_shared_report_groups"]
+        self, operation_name: ListSharedReportGroupsPaginatorName
     ) -> ListSharedReportGroupsPaginator:
         """
-        [Paginator.ListSharedReportGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedReportGroups)
+        [Paginator.ListSharedReportGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedReportGroups)
         """
